@@ -9,8 +9,7 @@ class ConsulService(object):
         '''初始化，连接consul服务器'''
         self._consul = consul.Consul(host, port)
 
-    def registerAPI(self, local_ip, port, app_name, app_id, prefix, app_group, instance_info, apis, protocol='http',
-                    health_entry='/health'):
+    def buildApiConfiguation(self, local_ip, port, app_name, app_id, prefix, app_group, instance_info, apis, protocol='http',health_entry='/health'):
         tags = []
 
         tags.append("group={}".format(app_group))
@@ -32,14 +31,21 @@ class ConsulService(object):
                 key = 'scopes'
             if key is not None:
                 tags.append("{}.middlewares=nezha@internal".format(route_prefix))
-                tags.extend(["{}.metadata.nezha.scopes={}".format(route_prefix, scope) for scope in api[key].split(',')])
+                tags.extend(
+                    ["{}.metadata.nezha.scopes={}".format(route_prefix, scope) for scope in api[key].split(',')])
 
         logging.info("Tags:" + str(tags))
+        api_info={"tags": tags,"local_ip":local_ip,"port":port,"app_id":app_id,"app_name":app_name,"app_group":app_group,"instance_info":instance_info,"protocol":protocol,"health_entry":health_entry}
+        return api_info
 
-        self.registerService(app_name, app_id, local_ip, port, tags=tags, protocol=protocol,
-                             health_entry=health_entry)
 
-        svc,res = self.getService(app_id)
+    def registerAPI(self, data):
+        #data=self.buildApiConfiguation(local_ip,port,app_name,app_id,perfix,app_group,instance_info,apis,protocol,health_entry)
+
+        self.registerService(data['app_name'], data['app_id'], data['local_ip'], data['port'], tags=data['tags'], protocol=data['protocol'],
+                             health_entry=data['health_entry'])
+
+        svc,res = self.getService(data['app_id'])
         logging.info(str(svc))
 
     def registerService(self, name, service_id, host, port, tags=None, protocol='http', health_entry='/health'):
@@ -104,9 +110,16 @@ if __name__ == '__main__':
     }
 ]
     consulService = ConsulService("consul", 8500)
-    consulService.registerAPI("10.5.0.25", 5000,'jx-attendance-api','jx-attandance-api-10-0-0-1', 'traefik', 'inhand-poweris',
+    data=consulService.buildApiConfiguation("10.5.84.37", 8069,'odoo-api','odoo-api-10-5-84-37', 'traefik', 'inhand-poweris',
                               {'verison':'v1.0.0'}, api_entries, protocol='http',
                     health_entry='/health')
+    with open('./api-info.json','w') as f:
+        json.dump(data,f)
+
+    with open('./api-info.json','r') as f:
+        data1=json.load(f)
+    consulService.registerAPI(data1)
+
 
 
 """
